Keen | General
Description: General widgets

# Customer Relationship Management

New Order

### General

Reports
08 Dec

### AirGreat Presentation

Oxfort Street
To start a blog, think of a topic about and first brainstorm ways to write details
+3
Join
23 Dec

### Christmas Party

Bolton House
To start a blog, think of a topic about and first brainstorm party is ways to write details
+5
Join
05 Jan

### Outdoor Activity Day

South Suton
To start a blog, think of a topic about and first brainstorm party is ways to write details
+3
Join
Announcements
Keen Admin Launch Day
To start a blog, think of a topic about and first brainstorm party is ways to write details
07 OCT, 2018
View
Incredibly Positive Reviews
To start a blog, think of a topic about and first brainstorm party is ways to write details
17 NOV, 2018
View
Award Winning Theme
To start a blog, think of a topic about and first brainstorm party is ways to write details
03 SEP, 2018
View
Projects
Keen Admin Launch Day
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
78%
First Milestone Achivement
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
55%
Reached 50,000 sales
To start a blog, think of a topic about and first brainstorm party is ways to write details
Progress
24%
Today's Schedule
Octa Pre-Launch Meeting
9:20AM - 10:00AM
490 E Main St. Norwich...
View Map
UI/UX Design Updates
11:15AM - 12:30PM
246 R St. Manhattan NY...
View Map
Sales Report Summary Meet-up
4:30PM - 5:30PM
492 F Sub St. Norwich CT...
View Map
Annual Profit
SAAS TOTAL PORIFT
$ 17M
CHANGE
+72%
Annual Sales
TOTAL SALES AMOUNT
920K
CHANGE
+85%
Response Rate
Support Quality
89%
CHANGE
+45%
New Products

### Active Smartwatch

Beautifully designed watch that helps you track your fitness and diet – while keeping you motivated!
246
Purchases
37
Reviews
24 Nov, 2018
Date of Release
Preview Details

### DSLR Lens

Wide-angle, Quick Focus. Emphasis is on modern lenses for 35 mm film SLRs and for DSLRs with sensor sizes less than or equal to 35 mm.
142
Purchases
25
Reviews
24 Nov, 2018
Date of Release
Preview Details

### Polaroid Camera

Instant is back! Make photos fun again with the new range of Polaroid Instant Cameras with Vintage Effects and Built in Flash
3578
Purchases
457
Reviews
24 Nov, 2018
Date of Release
Preview Details
New Authors
Andy John
AngularJS Expert
sale@boatline.com
(+44) 345 345 4705
01 Sep, 2018
Joined Date
Message Profile
Patrick Smith
ReactJS Expert
patrick@boatline.com
(+44) 345 345 5574
01 Sep, 2018
Joined Date
Message Profile
Amanda Collin
Project Manager
amanda@boatline.com
(+44) 345 345 1247
01 Sep, 2018
Joined Date
Message Profile

### Recent Works

Quickly direct you useful content or people
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Quickly direct you useful content or people
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Contain amazing email sign up form
HTML, CSS, JavaScripts
Get the point across
HTML, CSS, JavaScripts
Tips on How to Write an About me page
HTML, CSS, JavaScripts

### Latest Orders

Dark Blue Shoes - Limited Collection
SKU: 08451345264
$38.00 x 2
$76.00
Converse Sneakers - Red, Green & White
SKU: 08451345244
$92.00 x 1
$92.00
Merrell - Best Hiking Shoes
SKU: 08451345285
$224.00 x 1
$224.00
Ray Ban - Green Sunglasses
SKU: 08451345239
$109.00 x 3
$327.00
Preview Approve

### Latest Tasks

Management meeting
09:30 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
NYCS internal discussion
03: 00 PM
Project Launch
11: 00 AM
Server maintenance
4: 30 PM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Replace datatables rows color
12:00 AM
NYCS internal discussion
03: 00 PM
Management meeting
09:30 AM
NYCS internal discussion
03: 00 PM
Replace datatables rows color
12:00 AM
Replace datatables rows color
12:00 AM
Export Navitare booking table
01:20 PM
Export Navitare booking table
01:20 PM
Management meeting
09:30 AM

### Order Statistics

7,300
Total Orders
Mobile Games
Swift, Python, Java SDK
3,244 Orders
B2B2C Solutions
ASP.NET, Ruby, Python
962 Orders
HTML Templates
HTML, CSS, JS
2,750 Orders
Back-end Plugins
PHP, Ruby, C#, ASP.NET
890 Orders
Admin Software
Bootsrap, CSS, SCSS, AngularJS
1,644 Orders

### Notifications

02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User Preferences
Security, Fieewall
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User references
Security, Fieewall
May 09, 2018
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3
Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
PSD, Sketch, AJ
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
HTML,CSS,VueJS
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3
Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
PSD, Sketch, AJ
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User Preferences
Security, Fieewall
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take
aktion on User references
Security, Fieewall
May 09, 2018
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS
Yestardey
FlyMore design mock-ups been uploadet by
designers Bob, Naomi, Richard
HTML,CSS,VueJS
02:30 PM
KeenThemes created new layout whith tens of
new options for Keen Admin panel
HTML,CSS,VueJS

### Latest Uploads

All FILES
Keeg Design Reqs
95 MB
S.E.R Agreement
805 MB
FlyMore Screenshot
4 MB
ST.11 Dacuments
Unknown
XML AOL Data Fetchin
4 MB
Drag files here

### Work Progress

Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report
Pendings Tasks
78%
Completed Tasks
320 / 780
Tasks In Progress
45%
All Tasks
1200
Reports
40
Full Report

### Recent Orders 32500 total

Sort By:
New Record

### Daily Salles

CSV
Chris Bent
SUV Themes Carp
$ 830
Ashley Stock
Merscedes Benz AMGww
$ 675
Jimmy Yesuku
All Nippon United Airlines
$ 194
Amanda West
Comboy Westem Limited
$ 65
Nick Holms
UILab Inc
$ 65
Luke Davids Angular Developer Luke Davids Luke Davids
chat profile
AL
Ana Hope Web Designer
chat profile
Nicky Bold Project Manager
chat profile
Luke Davids Angular Developer
Progress 40
chat profile
Lara Nelson Product Manager
Progress 55
chat profile
Luke Davids Angular Developer
Progress 78
luke@loop.com
lukemanson
@lukemanson
246 Purchases
37 Reviews
07 Oct Joined Date
chat profile
Lara Nelson
It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.
luke@loop.com
lukemanson
chat profile

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!